@@ -24,7 +24,7 @@ impl Node {
 
 pub type NodeFieldList = &'static [&'static NodeField];
 
-#[derive(Debug, Clone, PartialEq)]
+#[derive(Debug, Clone)]
 pub struct NodeField {
     pub node: &'static Node,
     pub snakecase_name: &'static str,
@@ -33,6 +33,15 @@ pub struct NodeField {
     pub comment: &'static [&'static str],
 }
 
+impl PartialEq for NodeField {
+    fn eq(&self, other: &Self) -> bool {
+        self.snakecase_name == other.snakecase_name
+            && self.field_type == other.field_type
+            && self.always_print == other.always_print
+            && self.comment == other.comment
+    }
+}
+
 impl NodeField {
     pub fn render_comment(&self, prefix: &str, offset: usize) -> String {
         crate::comment::Comment::new(self.comment, prefix).to_string(offset)
